m_librarian.search module — Документация m_Librarian 0.1.2

# m_librarian.search module

`m_librarian.search.` `mk_search_conditions`(table, search_type, case_sensitive, values, expressions=None, join_expressions=None)

`m_librarian.search.` `search_authors`(search_type, case_sensitive, values, expressions=None, orderBy=None)

`m_librarian.search.` `search_books`(search_type, case_sensitive, values, join_expressions=None, orderBy=None)

`m_librarian.search.` `search_extensions`(search_type, case_sensitive, values, orderBy=None)

`m_librarian.search.` `search_genres`(search_type, case_sensitive, values, orderBy=None)

`m_librarian.search.` `search_languages`(search_type, case_sensitive, values, orderBy=None)